/* Parallel Hierarchical Grid -- an adaptive finite element library.
 *
 * Copyright (C) 2005-2009 State Key Laboratory of Scientific and
 * Engineering Computing, Chinese Academy of Sciences. */

/* This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA */

/* $Id: dof_info.c,v 1.4 2009/07/28 07:29:30 zlb Exp $ */

#include "phg.h"
#include <stdlib.h>
#include <string.h>

int
main(int argc, char *argv[])
{
    int n0, n1;

    phgInit(&argc, &argv);

    if (argc != 2) {
	phgPrintf("Print information about a DOF_TYPE.\n");
	phgPrintf("Usage: %s DOF_TYPE\n", argv[0]);
	phgPrintf("(\"%s -help generic\" to get a list of valid DOF_TYPEs)\n",
			argv[0]);
	phgFinalize();
	exit(1);
    }

    phgOptionsSetHandler("-dof_type", argv[1]);

    phgPrintf("DOF type \"%s\":\n", DOF_DEFAULT->name);

    phgPrintf("  F. E. space:       %s\n",
		phgDofFESpaceName(DOF_DEFAULT->fe_space));
    phgPrintf("  Order:             %d\n", DOF_DEFAULT->order);
    phgPrintf("  Dimension:         %d\n", DOF_DEFAULT->dim);
    phgPrintf("  Invariant:         %s\n",
		DOF_DEFAULT->invariant ? "yes" : "no");
    phgPrintf("  Continuity:        C(%d)\n", DOF_DEFAULT->continuity);
    phgPrintf("  Gradient type:     \"%s\"\n", DOF_DEFAULT->grad_type->name);

    phgPrintf("  Have nodal points: %s\n",
		DOF_DEFAULT->points != NULL ? "yes" : "no");

    phgPrintf("  Basis functions:   %d "
		"(vertex %d, edge %d, face %d, element %d)\n",
		DOF_DEFAULT->nbas, DOF_DEFAULT->np_vert, DOF_DEFAULT->np_edge,
		DOF_DEFAULT->np_face, DOF_DEFAULT->np_elem);
    phgPrintf("                     ");
    n0 = n1 = 0;
    if (DOF_DEFAULT->np_vert > 0) {
	n1 = n0 + DOF_DEFAULT->np_vert * NVert;
	phgPrintf("%s%d-%d: VERTEX", n0 == 0 ? "" : ", ", n0, n1 - 1);
	n0 = n1;
    }
    if (DOF_DEFAULT->np_edge > 0) {
	n1 = n0 + DOF_DEFAULT->np_edge * NEdge;
	phgPrintf("%s%d-%d: EDGE", n0 == 0 ? "" : ", ", n0, n1 - 1);
	n0 = n1;
    }
    if (DOF_DEFAULT->np_face > 0) {
	n1 = n0 + DOF_DEFAULT->np_face * NFace;
	phgPrintf("%s%d-%d: FACE", n0 == 0 ? "" : ", ", n0, n1 - 1);
	n0 = n1;
    }
    if (DOF_DEFAULT->np_elem > 0) {
	n1 = n0 + DOF_DEFAULT->np_elem;
	phgPrintf("%s%d-%d: ELEMENT", n0 == 0 ? "" : ", ", n0, n1 - 1);
	n0 = n1;
    }
    phgPrintf("\n");

    phgFinalize();

    return 0;
}
